@@ -36,8 +36,8 @@ sub configure {
         [ 'NameFromDirectory' ],
 
         # Make the git repo installable
-        [ 'Git::GatherDir', { exclude_filename => [ $self->build_file, 'META.json', @exclude_release ] } ],
-        [ 'CopyFilesFromBuild', { copy => [ 'META.json', $self->build_file ] } ],
+        [ 'Git::GatherDir', { exclude_filename => [ $self->build_file, 'META.json', 'LICENSE', @exclude_release ] } ],
+        [ 'CopyFilesFromBuild', { copy => [ 'META.json', 'LICENSE', $self->build_file ] } ],
 
         # should be after GatherDir
         # Equivalent to Module::Install's version_from, license_from and author_from
